# amigados-utils - Command line utilities for Amiga system development

## Description

This is a set of utilities to facilitate Amiga development in a Unix style
environment.

  * amigados-dir - dir utility for ADF files
  * amigados-copy - copy utility for ADF files
  * amigados-makedir - makedir utility for ADF files
  * amigados-createdisk - utility for creating ADF/HDF files
  * amigados-fdtool - replacement for fd2pragma (just started)
  * amigados-bumprev - replacement for BumpRev
  * amigados-dalf - replacement for Dalf (Amiga binary file viewer)
  * amigados-png2image - image converter

## Installation

pip install amigados-utils


## References

ROM Kernel Manuals: http://amigadev.elowar.com/
ADF format: http://lclevy.free.fr/adflib/adf_info.html


